pub enum CustomEncoding<'a> {
Format0(&'a [u8], &'a [Supplement]),
Format1(&'a [Range1], &'a [Supplement]),
}Expand description
Custom mapping from character codes to string ids.
Variants
Format0(&'a [u8], &'a [Supplement])
Sequence of character codes where the string id is equal to the index of the code plus one.
Format1(&'a [Range1], &'a [Supplement])
Sequence of ranges mapping character codes to string ids.
Implementations